==> pure-ftpd_1.0.22.orig.tar.gz: pure-ftpd-1.0.22.orig/src/messages_zh_tw.h <==
#define MSG_TIMEOUT "O"
#define MSG_CAPABILITIES "Lkʯ"
#define MSG_CLIENT_CLOSED_CNX "Τsu"
#define MSG_CLIENT_READ_ERR "qΤŪoͿ~"
#define MSG_CANT_OPEN_CNX "Lk}ҳsu"
#define MSG_CANT_CREATE_DATA_SOCKET "Lkإ߸Ʊf"
#define MSG_DEBUG_CLIENT_IS "Τݦ}O"
#define MSG_SYNTAX_ERROR_IP "yk~IP}"
#define MSG_PORT_SUCCESSFUL "PORTROOK"
#define MSG_ONLY_IPV4V6 "Ȥ䴩IPv4PIPv6 (1,2)"
#define MSG_ONLY_IPV4 "Ȥ䴩IPv4 (1)"
#define MSG_TIMEOUT_PARSER "O - U^ոպVɳtק֤@I"
#define MSG_LINE_TOO_LONG "ROL"
#define MSG_LOG_OVERFLOW "ΤխnROwİ"
#define MSG_GOODBYE "ACzW%lluäU%llu kbytes."
#define MSG_DEBUG_COMMAND "RO"
#define MSG_IS_YOUR_CURRENT_LOCATION "Ozثem"
#define MSG_NOT_LOGGED_IN "zånJ"
#define MSG_AUTH_UNIMPLEMENTED "wXRI"
#define MSG_NO_FILE_NAME "LɮצW"
#define MSG_NO_DIRECTORY_NAME "LؿW"
#define MSG_NO_RESTART_POINT "Ls}lI"
#define MSG_ABOR_SUCCESS "ABOR OK"
#define MSG_MISSING_ARG "򥢰Ѽ"
#define MSG_GARBAGE_FOUND "ѼƭȫᦳLΪr"
#define MSG_VALUE_TOO_LARGE "ѼƭȹLj"
#define MSG_IDLE_TIME "mɶ] %lu "
#define MSG_SITE_HELP "UCSITEROQ{i"
#define MSG_BAD_CHMOD "LĪv"
#define MSG_UNKNOWN_EXTENSION "OXR"
#define MSG_XDBG_OK "XDBGROOKA{ײ{bO %d"
#define MSG_UNKNOWN_COMMAND "RO"
#define MSG_TIMEOUT_NOOP "O (w %lu Lާ@)"
#define MSG_TIMEOUT_DATA "O (w %lu Ls)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "zwgnJ"
#define MSG_ANY_PASSWORD "KXi"
#define MSG_ANONYMOUS_LOGGED "ΦWϥΪ̵nJ"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "ΦWϥΪ̵nJFTP"
#define MSG_USER_OK "ϥΪ %s OK. ݭnKX."
#define MSG_CANT_DO_TWICE "bثesuo˰"
#define MSG_UNABLE_SECURE_ANON "LkإߦwΦWFTP"
#define MSG_BANDWIDTH_RESTRICTED "zWeϥΨ"
#define MSG_NO_PASSWORD_NEEDED "KXi"
#define MSG_NOTRUST "pAڵLkHz"
#define MSG_WHOAREYOU "ЧiDڧAO"
#define MSG_AUTH_FAILED "ҥѡAp"
#define MSG_AUTH_TOOMANY "ҥѤӦh"
#define MSG_NO_HOMEDIR "Saؿ - "
#define MSG_NO_HOMEDIR2 "%s sbεLkF"
#define MSG_START_SLASH "}l /"
#define MSG_USER_GROUP_ACCESS "ϥΪ %s sզs"
#define MSG_FXP_SUPPORT "oӦA䴩FXPǿ"
#define MSG_RATIO "zu %u:%u (UL/DL) v"
#define MSG_CHROOT_FAILED "Lk]wwchroot() jail"
#define MSG_CURRENT_DIR_IS "OK. ثeؿO %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. ثeؿO %s"
#define MSG_IS_NOW_LOGGED_IN "%s {bnJ"
#define MSG_CANT_CHANGE_DIR "Lkܧؿ %s"
#define MSG_PATH_TOO_LONG "|Ӫ"
#define MSG_CANT_PASV "zbIPv6suϥPASVCЧEPSVC"
#define MSG_CANT_PASSIVE "Lk}ҳQʦsu"
#define MSG_PORTS_BUSY "ҦOdTCP portsL"
#define MSG_GETSOCKNAME_DATA "LkѥƱf"
#define MSG_GETPEERNAME "Lkѥf"
#define MSG_INVALID_IP "pAOLĪ}"
#define MSG_NO_EPSV "ШϥβŦXIPv6ä䴩EPSVΤ"
#define MSG_BAD_PORT "pALksu ports < 1024"
#define MSG_NO_FXP "ڤ}ҳsu %s ( %s)"
#define MSG_FXP "FXPǿ: q %s  %s"
#define MSG_NO_DATA_CONN "LƳsu"
#define MSG_ACCEPT_FAILED "suLkQ"
#define MSG_ACCEPT_SUCCESS "Ƴsu"
#define MSG_CNX_PORT_FAILED "Lk}ҸƳsuport %d"
#define MSG_CNX_PORT "suport %d"
#define MSG_ANON_CANT_MKD "pAΦWϥΪ̫إߥؿ"
#define MSG_ANON_CANT_RMD "pAΦWϥΪ̲ؿ"
#define MSG_ANON_CANT_RENAME "ΦWϥΪ̷h/Wɮ"
#define MSG_ANON_CANT_CHANGE_PERMS "ΦWϥΪ̤ܧv"
#define MSG_GLOB_NO_MEMORY "Φ %s ɡAO餣"
#define MSG_PROBABLY_DENIED "(oiN \"vQ\")"
#define MSG_GLOB_READ_ERROR "Φ %s ɵoŪ~"
#define MSG_GLOB_NO_MATCH "SŦX %s A %s "
#define MSG_CHMOD_FAILED "ܧ %s v"
#define MSG_CHMOD_SUCCESS " %s vwܧ"
#define MSG_CHMOD_TOTAL_FAILURE "pAڵLkܧv"
#define MSG_ANON_CANT_DELETE "ΦWϥΪ̤Rɮ"
#define MSG_ANON_CANT_OVERWRITE "ΦWϥΪ̤мg{sɮ"
#define MSG_DELE_FAILED "LkR %s"
#define MSG_DELE_SUCCESS "R %s"
#define MSG_DELE_TOTAL_FAILURE "SRɮ"
#define MSG_LOAD_TOO_HIGH "zsuɭtO %3.2f CtpɡAڭ̤ΦWϥΪ̤UC\nWǫhOiH"



#define MSG_OPEN_FAILURE "Lk} %s"
#define MSG_OPEN_FAILURE2 "Lk}Ҩɮ"
#define MSG_STAT_FAILURE "Lkɮפjp"
#define MSG_STAT_FAILURE2 "Lkˬdɮתsb"
#define MSG_REST_TOO_LARGE_FOR_FILE "wɮפjp %lldɡAs}loffset %lld |LjC"
#define MSG_REST_RESET "offset] 0 s}l"
#define MSG_NOT_REGULAR_FILE "ڥu@ɮ"
#define MSG_NOT_MODERATED "ɥѰΦWϥΪ̤WǡC\n٨SQx޲z֭ѤUC"


#define MSG_RATIO_DENIAL "pAW/UvO %u:%u C\nzثeW %llu Kb U %llu KbC\nФWǤ@ǦnFMIAէC"



#define MSG_NO_MORE_TO_DOWNLOAD "wSFiU"
#define MSG_WINNER "qOzB͡CHq"
#define MSG_KBYTES_LEFT " %.1f kbytesnU"
#define MSG_ABORTED "ǿ餤"
#define MSG_DATA_WRITE_FAILED "ƳsugJɵoͿ~"
#define MSG_DATA_READ_FAILED "ƳsuŪɵoͿ~"
#define MSG_MMAP_FAILED "LkNɮmapiO"
#define MSG_WRITE_FAILED "gJɮ׮ɵoͿ~"
#define MSG_TRANSFER_RATE_M "%.3f  (ثe),C %.2f Mbytes"
#define MSG_TRANSFER_RATE_K "%.3f  (ثe),C %.2f Kbytes"
#define MSG_TRANSFER_RATE_B "%.3f  (ثe),C %.2f bytes"
#define MSG_SPACE_FREE_M "%.1f Mbytes ѾlwЪŶ"
#define MSG_SPACE_FREE_K "%f Kbytes ѾlwЪŶ"
#define MSG_DOWNLOADED "wU"
#define MSG_REST_NOT_NUMERIC "RESTݭnƦrѼ"
#define MSG_REST_ASCII_STRICT "bASCIIҦ^аOO 0"
#define MSG_REST_ASCII_WORKAROUND "s}l %lldCOڭ̦bASCIIҦ"
#define MSG_REST_SUCCESS "s}l %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "TΪؿW"
#define MSG_SANITY_FILE_FAILURE "TΪɦW: %s"
#define MSG_MKD_FAILURE "Lkإߥؿ"
#define MSG_MKD_SUCCESS "إߥؿOK"
#define MSG_RMD_FAILURE "Lkؿ"
#define MSG_RMD_SUCCESS "ؿOK"
#define MSG_TIMESTAMP_FAILURE "LkoɶWO"
#define MSG_MODE_ERROR "u䴩ASCIIbinaryҦ"
#define MSG_CREATE_FAILURE "Lkإɮ"
#define MSG_ABRT_ONLY "WǮABRTOߤ@ΪRO"
#define MSG_UPLOAD_PARTIAL "W"
#define MSG_REMOVED "F"
#define MSG_UPLOADED "WǤF"
#define MSG_GMTIME_FAILURE "Lkoaɶ"
#define MSG_TYPE_8BIT_FAILURE "u䴩8-bit bytesAڭ̤ObQ~e~N"
#define MSG_TYPE_UNKNOWN "TYPE"
#define MSG_TYPE_SUCCESS "TYPEثeO"
#define MSG_STRU_FAILURE "u䴩F(ile)"
#define MSG_MODE_FAILURE "ШϥS(tream)Ҧ"
#define MSG_RENAME_ABORT "eWާ@"
#define MSG_RENAME_RNFR_SUCCESS "RNFR - ɮצsbAǳƨتa"
#define MSG_FILE_DOESNT_EXIST "pAɮפsb"
#define MSG_RENAME_ALREADY_THERE "RENAME - تɮפwgsb"
#define MSG_RENAME_NORNFR "RNTOeݭnRNFR"
#define MSG_RENAME_FAILURE "W/ʥ"
#define MSG_RENAME_SUCCESS "ɮקW/OK"
#define MSG_NO_SUPERSERVER "Цbsuper-server (like tcpserver)pure-ftpd"
#define MSG_NO_FTP_ACCOUNT "Lk'ftp'b"
#define MSG_CONF_ERR "պA]w~"
#define MSG_NO_VIRTUAL_FILE "򥢵ϥΪɦW"
#define MSG_ILLEGAL_THROTTLING "Xk`y"
#define MSG_ILLEGAL_TRUSTED_GID "XkchrootHgid"
#define MSG_ILLEGAL_USER_LIMIT "XkϥΪ̭"
#define MSG_ILLEGAL_FACILITY "O]IW"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "LĪLDAPպAɮ"
#define MSG_ILLEGAL_LOAD_LIMIT "Xkt"
#define MSG_ILLEGAL_PORTS_RANGE "Xkfd"
#define MSG_ILLEGAL_LS_LIMITS "Xk'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "QʦsuɡAXkjIP"
#define MSG_ILLEGAL_RATIO "XkW/Uv"
#define MSG_ILLEGAL_UID_LIMIT "Xkuid"
#define MSG_ILLEGAL_OPTION "run-timeﶵ"
#define MSG_LDAP_MISSING_BASE "LDAPպAɤLDAPBaseDN"
#define MSG_LDAP_WRONG_PARMS "~LDAPѼ"
#define MSG_NEW_CONNECTION " %s ssu"
#define MSG_WELCOME_TO "wӨ"
#define MSG_MAX_USERS "%lu ϥΪ(̤j)wgnJAp"
#define MSG_NB_USERS "zO %d ӨϥΪ̡A̦hiF %d ӳsu"
#define MSG_WELCOME_TIME "{baɶO %02d:%02d CAf: %uC"
#define MSG_ANONYMOUS_FTP_ONLY "o̥uΰΦWFTP"
#define MSG_RATIOS_EVERYONE "wEVERYONEҥΤv:"
#define MSG_RATIOS_ANONYMOUS "ΦWϥΪ̳WwUL/DLv:"
#define MSG_RATIOS_RULE "nU %u Mb, qȤW %u Mb nFC"
#define MSG_INFO_IDLE_M "b %lu SʡAzQ|_uC"
#define MSG_INFO_IDLE_S "b %lu SʡAzQ|_uC"
#define MSG_CANT_READ_FILE "pAڭ̵LkŪ[%s]"
#define MSG_LS_TRUNCATED "XIu %u ŦX"
#define MSG_LS_SUCCESS "`@ %u ŦX"
#define MSG_LOGOUT "nX."
#define MSG_AUTH_FAILED_LOG "ϥΪ[%s]ҥ"
#define MSG_ILLEGAL_UMASK "LĪumask"
#define MSG_STANDALONE_FAILED "LkҰstandalone server"
#define MSG_NO_ANONYMOUS_LOGIN "oOpΨt - }ΦWnJ"
#define MSG_ANONYMOUS_ANY_PASSWORD "KXi"
#define MSG_MAX_USERS_IP "Ӧhsu (%lu) Ӧ۳o IP"
#define MSG_ACTIVE_DISABLED "DʼҦ"
#define MSG_TRANSFER_SUCCESSFUL "ɮ׶ǰeOK"
#define MSG_NO_DISK_SPACE "wz - бIW"
#define MSG_OUT_OF_MEMORY "O餣"
#define MSG_ILLEGAL_TRUSTED_IP "XkHIP}"
#define MSG_NO_ASCII_RESUME "ASCIIǨäwAХRɮ"
#define MSG_UNKNOWN_ALTLOG "Oɮ榡"
#define MSG_ACCOUNT_DISABLED "LknJ[%s]: b"
#define MSG_SQL_WRONG_PARMS "~SQLѼ"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "LĪSQL]w"
#define MSG_SQL_MISSING_SERVER "SQLպAɤ򥢦A]w"
#define MSG_SQL_DOWN "SQL servernF"
#define MSG_ILLEGAL_QUOTA "LĪB"
#define MSG_QUOTA_FILES "%llu ɮ׼ƨϥ (%d%%) - vi: %llu ɮ"
#define MSG_QUOTA_SIZE "%llu Kbytesϥ (%d%%) - vi: %llu Kb"
#define MSG_QUOTA_EXCEEDED "WLB: %s |Qxs"
#define MSG_AUTH_UNKNOWN "Ҥk"
#define MSG_PDB_BROKEN "LkŪindexed puredb(ΰ®榡) - ո pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s OOWA %s "
#define MSG_ALIASES_UNKNOWN "OW %sC"
#define MSG_ALIASES_BROKEN_FILE "laOWɮ"
#define MSG_ALIASES_LIST "HUOWiΡG"
#define MSG_PERUSER_MAX "LkӦۦP@ϥΪ̶WL %lu su"
#define MSG_IPV6_OK "oD]wIPv6su"
#define MSG_TLS_INFO "SSL/TLS: ҥ %s with %s, %d 줸[K"
#define MSG_TLS_WEAK "SSL/TLS: KX"
#define MSG_TLS_NEEDED "pAA妡suC\n" \
    "ШϥSSL/TLSwssuC"
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"

==> pure-ftpd_1.0.24.orig.tar.gz: pure-ftpd-1.0.24.orig/src/messages_zh_tw.h <==
#define MSG_TIMEOUT "O"
#define MSG_CAPABILITIES "Lkʯ"
#define MSG_CLIENT_CLOSED_CNX "Τsu"
#define MSG_CLIENT_READ_ERR "qΤŪoͿ~"
#define MSG_CANT_OPEN_CNX "Lk}ҳsu"
#define MSG_CANT_CREATE_DATA_SOCKET "Lkإ߸Ʊf"
#define MSG_DEBUG_CLIENT_IS "Τݦ}O"
#define MSG_SYNTAX_ERROR_IP "yk~IP}"
#define MSG_PORT_SUCCESSFUL "PORTROOK"
#define MSG_ONLY_IPV4V6 "Ȥ䴩IPv4PIPv6 (1,2)"
#define MSG_ONLY_IPV4 "Ȥ䴩IPv4 (1)"
#define MSG_TIMEOUT_PARSER "O - U^ոպVɳtק֤@I"
#define MSG_LINE_TOO_LONG "ROL"
#define MSG_LOG_OVERFLOW "ΤխnROwİ"
#define MSG_GOODBYE "ACzW%lluäU%llu kbytes."
#define MSG_DEBUG_COMMAND "RO"
#define MSG_IS_YOUR_CURRENT_LOCATION "Ozثem"
#define MSG_NOT_LOGGED_IN "zånJ"
#define MSG_AUTH_UNIMPLEMENTED "wXRI"
#define MSG_NO_FILE_NAME "LɮצW"
#define MSG_NO_DIRECTORY_NAME "LؿW"
#define MSG_NO_RESTART_POINT "Ls}lI"
#define MSG_ABOR_SUCCESS "ABOR OK"
#define MSG_MISSING_ARG "򥢰Ѽ"
#define MSG_GARBAGE_FOUND "ѼƭȫᦳLΪr"
#define MSG_VALUE_TOO_LARGE "ѼƭȹLj"
#define MSG_IDLE_TIME "mɶ] %lu "
#define MSG_SITE_HELP "UCSITEROQ{i"
#define MSG_BAD_CHMOD "LĪv"
#define MSG_UNKNOWN_EXTENSION "OXR"
#define MSG_XDBG_OK "XDBGROOKA{ײ{bO %d"
#define MSG_UNKNOWN_COMMAND "RO"
#define MSG_TIMEOUT_NOOP "O (w %lu Lާ@)"
#define MSG_TIMEOUT_DATA "O (w %lu Ls)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "zwgnJ"
#define MSG_ANY_PASSWORD "KXi"
#define MSG_ANONYMOUS_LOGGED "ΦWϥΪ̵nJ"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "ΦWϥΪ̵nJFTP"
#define MSG_USER_OK "ϥΪ %s OK. ݭnKX."
#define MSG_CANT_DO_TWICE "bثesuo˰"
#define MSG_UNABLE_SECURE_ANON "LkإߦwΦWFTP"
#define MSG_BANDWIDTH_RESTRICTED "zWeϥΨ"
#define MSG_NO_PASSWORD_NEEDED "KXi"
#define MSG_NOTRUST "pAڵLkHz"
#define MSG_WHOAREYOU "ЧiDڧAO"
#define MSG_AUTH_FAILED "ҥѡAp"
#define MSG_AUTH_TOOMANY "ҥѤӦh"
#define MSG_NO_HOMEDIR "Saؿ - "
#define MSG_NO_HOMEDIR2 "%s sbεLkF"
#define MSG_START_SLASH "}l /"
#define MSG_USER_GROUP_ACCESS "ϥΪ %s sզs"
#define MSG_FXP_SUPPORT "oӦA䴩FXPǿ"
#define MSG_RATIO "zu %u:%u (UL/DL) v"
#define MSG_CHROOT_FAILED "Lk]wwchroot() jail"
#define MSG_CURRENT_DIR_IS "OK. ثeؿO %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. ثeؿO %s"
#define MSG_IS_NOW_LOGGED_IN "%s {bnJ"
#define MSG_CANT_CHANGE_DIR "Lkܧؿ %s"
#define MSG_PATH_TOO_LONG "|Ӫ"
#define MSG_CANT_PASV "zbIPv6suϥPASVCЧEPSVC"
#define MSG_CANT_PASSIVE "Lk}ҳQʦsu"
#define MSG_PORTS_BUSY "ҦOdTCP portsL"
#define MSG_GETSOCKNAME_DATA "LkѥƱf"
#define MSG_GETPEERNAME "Lkѥf"
#define MSG_INVALID_IP "pAOLĪ}"
#define MSG_NO_EPSV "ШϥβŦXIPv6ä䴩EPSVΤ"
#define MSG_BAD_PORT "pALksu ports < 1024"
#define MSG_NO_FXP "ڤ}ҳsu %s ( %s)"
#define MSG_FXP "FXPǿ: q %s  %s"
#define MSG_NO_DATA_CONN "LƳsu"
#define MSG_ACCEPT_FAILED "suLkQ"
#define MSG_ACCEPT_SUCCESS "Ƴsu"
#define MSG_CNX_PORT_FAILED "Lk}ҸƳsuport %d"
#define MSG_CNX_PORT "suport %d"
#define MSG_ANON_CANT_MKD "pAΦWϥΪ̫إߥؿ"
#define MSG_ANON_CANT_RMD "pAΦWϥΪ̲ؿ"
#define MSG_ANON_CANT_RENAME "ΦWϥΪ̷h/Wɮ"
#define MSG_ANON_CANT_CHANGE_PERMS "ΦWϥΪ̤ܧv"
#define MSG_GLOB_NO_MEMORY "Φ %s ɡAO餣"
#define MSG_PROBABLY_DENIED "(oiN \"vQ\")"
#define MSG_GLOB_READ_ERROR "Φ %s ɵoŪ~"
#define MSG_GLOB_NO_MATCH "SŦX %s A %s "
#define MSG_CHMOD_FAILED "ܧ %s v"
#define MSG_CHMOD_SUCCESS " %s vwܧ"
#define MSG_CHMOD_TOTAL_FAILURE "pAڵLkܧv"
#define MSG_ANON_CANT_DELETE "ΦWϥΪ̤Rɮ"
#define MSG_ANON_CANT_OVERWRITE "ΦWϥΪ̤мg{sɮ"
#define MSG_DELE_FAILED "LkR %s"
#define MSG_DELE_SUCCESS "R %s"
#define MSG_DELE_TOTAL_FAILURE "SRɮ"
#define MSG_LOAD_TOO_HIGH "zsuɭtO %3.2f CtpɡAڭ̤ΦWϥΪ̤UC\nWǫhOiH"



#define MSG_OPEN_FAILURE "Lk} %s"
#define MSG_OPEN_FAILURE2 "Lk}Ҩɮ"
#define MSG_STAT_FAILURE "Lkɮפjp"
#define MSG_STAT_FAILURE2 "Lkˬdɮתsb"
#define MSG_REST_TOO_LARGE_FOR_FILE "wɮפjp %lldɡAs}loffset %lld |LjC"
#define MSG_REST_RESET "offset] 0 s}l"
#define MSG_NOT_REGULAR_FILE "ڥu@ɮ"
#define MSG_NOT_MODERATED "ɥѰΦWϥΪ̤WǡC\n٨SQx޲z֭ѤUC"


#define MSG_RATIO_DENIAL "pAW/UvO %u:%u C\nzثeW %llu Kb U %llu KbC\nФWǤ@ǦnFMIAէC"



#define MSG_NO_MORE_TO_DOWNLOAD "wSFiU"
#define MSG_WINNER "qOzB͡CHq"
#define MSG_KBYTES_LEFT " %.1f kbytesnU"
#define MSG_ABORTED "ǿ餤"
#define MSG_DATA_WRITE_FAILED "ƳsugJɵoͿ~"
#define MSG_DATA_READ_FAILED "ƳsuŪɵoͿ~"
#define MSG_MMAP_FAILED "LkNɮmapiO"
#define MSG_WRITE_FAILED "gJɮ׮ɵoͿ~"
#define MSG_TRANSFER_RATE_M "%.3f  (ثe),C %.2f Mbytes"
#define MSG_TRANSFER_RATE_K "%.3f  (ثe),C %.2f Kbytes"
#define MSG_TRANSFER_RATE_B "%.3f  (ثe),C %.2f bytes"
#define MSG_SPACE_FREE_M "%.1f Mbytes ѾlwЪŶ"
#define MSG_SPACE_FREE_K "%f Kbytes ѾlwЪŶ"
#define MSG_DOWNLOADED "wU"
#define MSG_REST_NOT_NUMERIC "RESTݭnƦrѼ"
#define MSG_REST_ASCII_STRICT "bASCIIҦ^аOO 0"
#define MSG_REST_ASCII_WORKAROUND "s}l %lldCOڭ̦bASCIIҦ"
#define MSG_REST_SUCCESS "s}l %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "TΪؿW"
#define MSG_SANITY_FILE_FAILURE "TΪɦW: %s"
#define MSG_MKD_FAILURE "Lkإߥؿ"
#define MSG_MKD_SUCCESS "إߥؿOK"
#define MSG_RMD_FAILURE "Lkؿ"
#define MSG_RMD_SUCCESS "ؿOK"
#define MSG_TIMESTAMP_FAILURE "LkoɶWO"
#define MSG_MODE_ERROR "u䴩ASCIIbinaryҦ"
#define MSG_CREATE_FAILURE "Lkإɮ"
#define MSG_ABRT_ONLY "WǮABRTOߤ@ΪRO"
#define MSG_UPLOAD_PARTIAL "W"
#define MSG_REMOVED "F"
#define MSG_UPLOADED "WǤF"
#define MSG_GMTIME_FAILURE "Lkoaɶ"
#define MSG_TYPE_8BIT_FAILURE "u䴩8-bit bytesAڭ̤ObQ~e~N"
#define MSG_TYPE_UNKNOWN "TYPE"
#define MSG_TYPE_SUCCESS "TYPEثeO"
#define MSG_STRU_FAILURE "u䴩F(ile)"
#define MSG_MODE_FAILURE "ШϥS(tream)Ҧ"
#define MSG_RENAME_ABORT "eWާ@"
#define MSG_RENAME_RNFR_SUCCESS "RNFR - ɮצsbAǳƨتa"
#define MSG_FILE_DOESNT_EXIST "pAɮפsb"
#define MSG_RENAME_ALREADY_THERE "RENAME - تɮפwgsb"
#define MSG_RENAME_NORNFR "RNTOeݭnRNFR"
#define MSG_RENAME_FAILURE "W/ʥ"
#define MSG_RENAME_SUCCESS "ɮקW/OK"
#define MSG_NO_SUPERSERVER "Цbsuper-server (like tcpserver)pure-ftpd"
#define MSG_NO_FTP_ACCOUNT "Lk'ftp'b"
#define MSG_CONF_ERR "պA]w~"
#define MSG_NO_VIRTUAL_FILE "򥢵ϥΪɦW"
#define MSG_ILLEGAL_THROTTLING "Xk`y"
#define MSG_ILLEGAL_TRUSTED_GID "XkchrootHgid"
#define MSG_ILLEGAL_USER_LIMIT "XkϥΪ̭"
#define MSG_ILLEGAL_FACILITY "O]IW"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "LĪLDAPպAɮ"
#define MSG_ILLEGAL_LOAD_LIMIT "Xkt"
#define MSG_ILLEGAL_PORTS_RANGE "Xkfd"
#define MSG_ILLEGAL_LS_LIMITS "Xk'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "QʦsuɡAXkjIP"
#define MSG_ILLEGAL_RATIO "XkW/Uv"
#define MSG_ILLEGAL_UID_LIMIT "Xkuid"
#define MSG_ILLEGAL_OPTION "run-timeﶵ"
#define MSG_LDAP_MISSING_BASE "LDAPպAɤLDAPBaseDN"
#define MSG_LDAP_WRONG_PARMS "~LDAPѼ"
#define MSG_NEW_CONNECTION " %s ssu"
#define MSG_WELCOME_TO "wӨ"
#define MSG_MAX_USERS "%lu ϥΪ(̤j)wgnJAp"
#define MSG_NB_USERS "zO %d ӨϥΪ̡A̦hiF %d ӳsu"
#define MSG_WELCOME_TIME "{baɶO %02d:%02d CAf: %uC"
#define MSG_ANONYMOUS_FTP_ONLY "o̥uΰΦWFTP"
#define MSG_RATIOS_EVERYONE "wEVERYONEҥΤv:"
#define MSG_RATIOS_ANONYMOUS "ΦWϥΪ̳WwUL/DLv:"
#define MSG_RATIOS_RULE "nU %u Mb, qȤW %u Mb nFC"
#define MSG_INFO_IDLE_M "b %lu SʡAzQ|_uC"
#define MSG_INFO_IDLE_S "b %lu SʡAzQ|_uC"
#define MSG_CANT_READ_FILE "pAڭ̵LkŪ[%s]"
#define MSG_LS_TRUNCATED "XIu %u ŦX"
#define MSG_LS_SUCCESS "`@ %u ŦX"
#define MSG_LOGOUT "nX."
#define MSG_AUTH_FAILED_LOG "ϥΪ[%s]ҥ"
#define MSG_ILLEGAL_UMASK "LĪumask"
#define MSG_STANDALONE_FAILED "LkҰstandalone server"
#define MSG_NO_ANONYMOUS_LOGIN "oOpΨt - }ΦWnJ"
#define MSG_ANONYMOUS_ANY_PASSWORD "KXi"
#define MSG_MAX_USERS_IP "Ӧhsu (%lu) Ӧ۳o IP"
#define MSG_ACTIVE_DISABLED "DʼҦ"
#define MSG_TRANSFER_SUCCESSFUL "ɮ׶ǰeOK"
#define MSG_NO_DISK_SPACE "wz - бIW"
#define MSG_OUT_OF_MEMORY "O餣"
#define MSG_ILLEGAL_TRUSTED_IP "XkHIP}"
#define MSG_NO_ASCII_RESUME "ASCIIǨäwAХRɮ"
#define MSG_UNKNOWN_ALTLOG "Oɮ榡"
#define MSG_ACCOUNT_DISABLED "LknJ[%s]: b"
#define MSG_SQL_WRONG_PARMS "~SQLѼ"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "LĪSQL]w"
#define MSG_SQL_MISSING_SERVER "SQLպAɤ򥢦A]w"
#define MSG_SQL_DOWN "SQL servernF"
#define MSG_ILLEGAL_QUOTA "LĪB"
#define MSG_QUOTA_FILES "%llu ɮ׼ƨϥ (%d%%) - vi: %llu ɮ"
#define MSG_QUOTA_SIZE "%llu Kbytesϥ (%d%%) - vi: %llu Kb"
#define MSG_QUOTA_EXCEEDED "WLB: [%s] |Qxs"
#define MSG_AUTH_UNKNOWN "Ҥk"
#define MSG_PDB_BROKEN "LkŪindexed puredb(ΰ®榡) - ո pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s OOWA %s "
#define MSG_ALIASES_UNKNOWN "OW %sC"
#define MSG_ALIASES_BROKEN_FILE "laOWɮ"
#define MSG_ALIASES_LIST "HUOWiΡG"
#define MSG_PERUSER_MAX "LkӦۦP@ϥΪ̶WL %lu su"
#define MSG_IPV6_OK "oD]wIPv6su"
#define MSG_TLS_INFO "SSL/TLS: ҥ %s with %s, %d 줸[K"
#define MSG_TLS_WEAK "SSL/TLS: KX"
#define MSG_TLS_NEEDED "pAA妡suC\n" \
    "ШϥSSL/TLSwssuC"
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
